import React from 'react';
import { LinkExtend, DynamicRedirect, UTMBuilderPro, BuiltInUTMBuilder } from './../../components';
import { user_can_write_links, user_can_view_links, user_can_edit_links, user_can_manage_options, getJsonString, route_path, user_can_edit_favorite } from './../../utils/helper';
import { __ } from '@wordpress/i18n';
betterLinksHooks.addFilter('linkFormInitialValues', 'betterlinks', (initialValues, setFieldValue) => {
	let { expire, dynamic_redirect } = initialValues;
	if (expire && typeof expire === 'string') {
		expire = JSON.parse(expire);
	}
	if (dynamic_redirect && typeof dynamic_redirect === 'string') {
		dynamic_redirect = JSON.parse(dynamic_redirect);
	}

	initialValues.expire = {
		status: false,
		type: 'date',
		clicks: '',
		date: '',
		redirect_status: false,
		redirect_url: '',
		...expire,
	};

	initialValues.dynamic_redirect = {
		type: '',
		value: [],
		extra: {
			rotation_mode: 'weighted',
			split_test: false,
			goal_link: '',
		},
		...dynamic_redirect,
	};

	return initialValues;
});

betterLinksHooks.addFilter('linkOptionsAdvanced', 'betterlinks', (content, props) => {
	return <LinkExtend values={props.values} setFieldValue={props.setFieldValue} />;
});

betterLinksHooks.addFilter('linkOptionsDynamicRedirect', 'betterlinks', (content, props) => {
	return <DynamicRedirect values={props.values} setFieldValue={props.setFieldValue} />;
});

betterLinksHooks.addFilter('linkQuickActionNewField', 'betterlinks', (content, data) => {
	if (data.dynamic_redirect) {
		const dynamic_redirect = getJsonString(data.dynamic_redirect);
		if (dynamic_redirect && dynamic_redirect.type === 'rotation' && dynamic_redirect.extra && dynamic_redirect.extra.split_test == true) {
			return (
				<a className="dnd-link-button btl-tooltip" href={route_path + 'admin.php?page=betterlinks-analytics&id=' + data.ID + '&split-test=' + true}>
					<i className="btl btl-abtesting"></i>
					<span className="btl-tooltiptext">{__('Split Test Analytics', 'betterlinks-pro')}</span>
				</a>
			);
		}
	}
	return;
});

betterLinksHooks.addFilter('linksUTMBuilderField', 'betterlinks', (content, target_url, setFieldValue, closeUTMModal) => {
	return <UTMBuilderPro targetUrl={target_url} setFieldValue={setFieldValue} closeUTMModal={closeUTMModal} />;
});

betterLinksHooks.addFilter('linksBuiltInUTMBuilderField', 'betterlinks', (content, target_url, setFieldValue, closeUTMModal) => {
	return <BuiltInUTMBuilder targetUrl={target_url} setFieldValue={setFieldValue} closeUTMModal={closeUTMModal} />;
});
betterLinksHooks.addFilter('isShowManageLinksMenu', 'betterlinks', () => {
	return !!user_can_write_links || !!user_can_edit_links || !!user_can_view_links;
});
betterLinksHooks.addFilter('betterLinksIsShowWriteLink', 'betterlinks', () => {
	return !!user_can_write_links;
});
betterLinksHooks.addFilter('betterLinksIsShowViewLink', 'betterlinks', () => {
	return !!user_can_edit_links || !!user_can_view_links;
});
betterLinksHooks.addFilter('betterLinksIsShowEditLink', 'betterlinks', () => {
	return !!user_can_edit_links;
});
betterLinksHooks.addFilter('betterLinksIsShowFavorite', 'betterlinks', () => {
	return !!user_can_edit_favorite;
});
betterLinksHooks.addFilter('betterLinksIsShowDeleteLink', 'betterlinks', () => {
	return !!user_can_manage_options;
});
betterLinksHooks.addFilter('isShowLinkSubmitButton', 'betterlinks', (currentStatus, data) => {
	if (data && !!user_can_edit_links == true) {
		return true;
	} else if (!data && !!user_can_write_links == true) {
		return true;
	}
	return false;
});
betterLinksHooks.addFilter('isDisableLinkFormEditView', 'betterlinks', (currentStatus, data) => {
	if (!data) {
		return false;
	}
	if (!!user_can_view_links === true && !!user_can_edit_links == false) {
		return true;
	}
	return false;
});
