import React from 'react';
import { __ } from '@wordpress/i18n';
import { RoleManagement, GoogleAnalytics, BrokenLinks, License } from './../../components';
import { user_can_edit_settings } from './../../utils/helper';

betterLinksHooks.addFilter('BetterLinksAddOptionSettingsTabGeneral', 'betterlinks', (content, props) => {
	const is_autolink_headings = typeof props.values.is_autolink_headings === 'undefined' ? true : props.values.is_autolink_headings;
	return (
		<>
			<span className="btl-form-group btl-form-group--top">
				<label className="btl-form-label">{__('Force HTTPS', 'betterlinks-pro')}</label>
				<div className="btl-form-field">
					<label className="btl-checkbox-field block">
						<input
							className="btl-check"
							name="force_https"
							type="checkbox"
							onChange={() => props.setFieldValue('force_https', !props.values.force_https)}
							checked={props.values.force_https === true}
						/>
						<span className="text">
							{__('Enable HTTPS Redirection', 'betterlinks-pro')}
							<div className="btl-tooltip">
								<span className="dashicons dashicons-info-outline"></span>
								<span className="btl-tooltiptext">{__('This will allow you to redirect your Target URLs in HTTPS.', 'betterlinks-pro')}</span>
							</div>
						</span>
					</label>
					<div className="short-description">
						<b style={{ fontWeight: '700' }}>{__('Note:', 'betterlinks-pro')} </b>
						{__('For this feature to work, make sure that the website where you are trying to redirect has SSL configured.', 'betterlinks-pro')}
					</div>
				</div>
			</span>

			<span className="btl-form-group btl-form-group-autolink-keyword-icon">
				<label className="btl-form-label">{__('Auto-Linked Keywords Icon', 'betterlinks-pro')}</label>
				<div className="btl-form-field">
					<label className="btl-checkbox-field block">
						<input
							className="btl-check"
							name="is_autolink_icon"
							type="checkbox"
							onChange={() => props.setFieldValue('is_autolink_icon', !props.values.is_autolink_icon)}
							checked={props.values.is_autolink_icon === true}
						/>
						<span className="text">
							{__('Enable Icon for Auto-Linked Keywords', 'betterlinks-pro')}
							<div className="btl-tooltip">
								<span className="dashicons dashicons-info-outline"></span>
								<span className="btl-tooltiptext">{__('If enabled, this will show a affiliate link icon beside your auto-linked keywords', 'betterlinks-pro')}</span>
							</div>
						</span>
					</label>
				</div>
			</span>

			<span className="btl-form-group ">
				<label className="btl-form-label">
					{__('Auto-Link Keywords inside ', 'betterlinks-pro')}
					<span style={{ display: 'block' }}>{__('Headings', 'betterlinks-pro')}</span>
				</label>
				<div className="btl-form-field">
					<label className="btl-checkbox-field block">
						<input
							className="btl-check"
							name="is_autolink_headings"
							type="checkbox"
							onChange={() => props.setFieldValue('is_autolink_headings', !is_autolink_headings)}
							checked={is_autolink_headings === true}
						/>
						<span className="text">
							{__('Enable Auto-Link Keywords inside Heading Tags (h1-h6)', 'betterlinks-pro')}
							<div className="btl-tooltip">
								<span className="dashicons dashicons-info-outline"></span>
								<span className="btl-tooltiptext">{__('if enabled, keywords will be automatically linked in the heading tags as well.', 'betterlinks-pro')}</span>
							</div>
						</span>
					</label>
				</div>
			</span>
		</>
	);
});
betterLinksHooks.addFilter('betterLinksSettingsFilterTabList', 'betterlinks', (tabItem) => {
	const newTabItem = tabItem.filter((item, index) => {
		return index < 2;
	});
	newTabItem.push(
		__('Role Management', 'betterlinks-pro'),
		__('Google Analytics', 'betterlinks-pro'),
		__('Broken Link Checker', 'betterlinks-pro'),
		__('License', 'betterlinks-pro')
	);
	return newTabItem;
});
betterLinksHooks.addFilter('betterLinksSettingsFilterTabPanel', 'betterlinks', (tabPanel) => {
	const newTabPanel = tabPanel.filter((item, index) => {
		return index < 2;
	});
	newTabPanel.push(<RoleManagement />, <GoogleAnalytics />, <BrokenLinks />, <License />);
	return newTabPanel;
});
betterLinksHooks.addFilter('isShowSettingsMenu', 'betterlinks', () => {
	return !!user_can_edit_settings;
});
