import React, { useState, useEffect } from 'react';
import { Formik, Field, Form } from 'formik';
import { __ } from '@wordpress/i18n';
import { makeRequest, delayStatusChanged } from './../../utils/helper';
import PropTypes from 'prop-types';

const propTypes = {};

const defaultProps = {};

export default function Reporting(props) {
	const [reportingButtonText, setReportingButtonText] = useState(__('Save Settings', 'betterlinks-pro'));
	const [testReportButtonText, setTestReportButtonText] = useState(__('Test Report', 'betterlinks-pro'));
	const [settings, setSettings] = useState({
		enable_reporting: true,
		email: '',
		email_subject: '',
	});
	useEffect(() => {
		makeRequest({
			action: 'betterlinkspro/admin/get_reporting_settings',
		}).then((response) => {
			if (response.data.data) {
				const settings = JSON.parse(response.data.data);
				setSettings({ ...settings });
			}
		});
	}, []);

	const testMailHandler = () => {
		setTestReportButtonText(__('Email Sending..', 'betterlinks-pro'));
		makeRequest({
			action: 'betterlinkspro/admin/test_report_mail',
		}).then((response) => {
			if (response.data.data) {
				const settings = JSON.parse(response.data.data);
				setSettings({ ...settings });
				delayStatusChanged(__('Email Sending...', 'betterlinks-pro'), __('Email Sent', 'betterlinks-pro'), __('Test Report', 'betterlinks-pro'), setTestReportButtonText);
			} else {
				delayStatusChanged(__('Email Sending...', 'betterlinks-pro'), __('Failed Delivery', 'betterlinks-pro'), __('Test Report', 'betterlinks-pro'), setTestReportButtonText);
			}
		});
	};

	return (
		<React.Fragment>
			<Formik
				enableReinitialize
				initialValues={settings}
				onSubmit={async (values, { resetForm }) => {
					makeRequest({
						action: 'betterlinkspro/admin/saved_reporting_settings',
						...values,
					}).then((response) => {
						if (response.data.data) {
							delayStatusChanged(__('Saving...', 'betterlinks-pro'), __('Saved!', 'betterlinks-pro'), __('Save Settings', 'betterlinks-pro'), setReportingButtonText);
							window.setTimeout(() => {
								resetForm({ values });
							}, 3000);
						}
					});
				}}
			>
				{(props) => (
					<Form>
						<span className="btl-form-group">
							<label className="btl-form-label">{__('Enable Reporting', 'betterlinks-pro')}</label>
							<div className="link-options__body">
								<label className="btl-checkbox-field block">
									<Field type="checkbox" id="enable_reporting" name="enable_reporting" />
								</label>
							</div>
						</span>
						<span className="btl-form-group">
							<label className="btl-form-label">{__('Reporting Email', 'betterlinks-pro')}</label>
							<div className="link-options__body">
								<label className="btl-checkbox-field block">
									<Field type="text" id="email" name="email" className="btl-form-control" />
								</label>
							</div>
						</span>
						<span className="btl-form-group">
							<label className="btl-form-label">{__('Reporting Email Subject', 'betterlinks-pro')}</label>
							<div className="link-options__body">
								<label className="btl-checkbox-field block">
									<Field type="text" id="email_subject" name="email_subject" className="btl-form-control" />
								</label>
							</div>
						</span>
						{!props.dirty && (
							<span className="btl-form-group">
								<label className="btl-form-label">{__('Reporting Test', 'betterlinks-pro')}</label>
								<div className="link-options__body">
									<label className="btl-checkbox-field block">
										<button
											type="button"
											className={`${testReportButtonText == 'Email Sent' ? 'btl-success' : testReportButtonText == 'Failed Delivery' ? 'btl-danger' : ''}`}
											onClick={() => testMailHandler()}
										>
											{testReportButtonText}
										</button>
									</label>
								</div>
							</span>
						)}
						{props.dirty && (
							<span className="btl-form-group">
								<button className="btl-filled-button" type="submit">
									{reportingButtonText}
								</button>
							</span>
						)}
					</Form>
				)}
			</Formik>
		</React.Fragment>
	);
}

Reporting.propTypes = propTypes;
Reporting.defaultProps = defaultProps;
