import React, { useState, useEffect } from 'react';
import { Formik, Field, Form } from 'formik';
import { __ } from '@wordpress/i18n';
import Select from 'react-select';
import { MuiPickersUtilsProvider } from '@material-ui/pickers';
import { TimePicker } from 'formik-material-ui-pickers';
import DateFnsUtils from '@date-io/date-fns';
import { makeRequest, delayStatusChanged, frequentlyOption, weekOption } from './../../utils/helper';
import PropTypes from 'prop-types';

const propTypes = {};

const defaultProps = {};

export default function ScheduleScan(props) {
	const [scheduleButtonText, setScheduleButtonText] = useState('Save Settings');
	const [settings, setSettings] = useState({
		enable_scan: false,
		scan_mode: 'weekly',
		scan_day: 'sunday',
		scan_time: '',
	});

	useEffect(() => {
		makeRequest({
			action: 'betterlinkspro/admin/get_broken_link_settings',
		}).then((response) => {
			if (response.data.data) {
				const settings = JSON.parse(response.data.data);
				setSettings({ ...settings, scan_time: settings.scan_time ? new Date(settings.scan_time.substring(2, settings.scan_time.length - 2)) : new Date() });
			}
		});
	}, []);
	return (
		<React.Fragment>
			<h3>{__('Scheduled Scan', 'betterlinks-pro')}</h3>
			<p>
				{__('Enable', 'betterlinks-pro')} <strong>{__('"Scheduled Scan"', 'betterlinks-pro')}</strong>{' '}
				{__('to automatically scan broken links on your website.', 'betterlinks-pro')}
			</p>
			<Formik
				enableReinitialize
				initialValues={settings}
				onSubmit={async (values) => {
					makeRequest({
						action: 'betterlinkspro/admin/save_broken_link_settings',
						...values,
					}).then((response) => {
						if (response.data.data) {
							delayStatusChanged(__('Saving..', 'betterlinks-pro'), __('Saved!', 'betterlinks-pro'), __('Save Settings', 'betterlinks-pro'), setScheduleButtonText);
						}
					});
				}}
			>
				{(props) => (
					<MuiPickersUtilsProvider utils={DateFnsUtils}>
						<Form>
							<div className="btl-role-item btl-form-group">
								<label className="btl-form-label">{__('Enable Scheduled Scan', 'betterlinks-pro')}</label>
								<div className="link-options__body">
									<label className="btl-checkbox-field">
										<Field type="checkbox" id="enable_scan" name="enable_scan" />
									</label>
								</div>
							</div>
							<div className="btl-form-group">
								<label className="btl-form-label">{__('Frequency', 'betterlinks-pro')}</label>
								<div className="link-options__body">
									<Select
										className="btl-select"
										classNamePrefix="btl"
										value={frequentlyOption.filter((item, index) => item.value == props.values.scan_mode)}
										name="scan_mode"
										options={frequentlyOption}
										onChange={(option) => props.setFieldValue('scan_mode', option.value)}
									/>
								</div>
							</div>
							<div className="btl-form-group">
								<label className="btl-form-label">{__('Day', 'betterlinks-pro')}</label>
								<div className="link-options__body">
									<div className="scheduleweekdayselect">
										{weekOption.map((day, index) => (
											<label key={index}>
												<Field type="radio" name="scan_day" value={day.toLowerCase()} />
												<span>{day.slice(0, 3)}</span>
											</label>
										))}
									</div>
								</div>
							</div>
							<div className="btl-form-group">
								<label className="btl-form-label">{__('Time', 'betterlinks-pro')}</label>
								<div className="link-options__body">
									<Field
										component={TimePicker}
										name="scan_time"
										value={props.values.scan_time == 'Invalid Date' ? new Date() : props.values.scan_time}
										onChange={(time) => props.setFieldValue('scan_time', time)}
									/>
								</div>
							</div>
							{props.dirty && (
								<div className="btl-form-group">
									<label className="btl-form-label"></label>
									<div className="link-options__body">
										<button className="btl-filled-button" type="submit">
											{scheduleButtonText}
										</button>
									</div>
								</div>
							)}
						</Form>
					</MuiPickersUtilsProvider>
				)}
			</Formik>
		</React.Fragment>
	);
}

ScheduleScan.propTypes = propTypes;
ScheduleScan.defaultProps = defaultProps;
