import React, { useState, useEffect } from 'react';
import { __ } from '@wordpress/i18n';
import DataTable from 'react-data-table-component';
import Select from 'react-select';
import { Button } from '@wordpress/components';
import Modal from 'react-modal';
import { site_url, copyToClipboard, makeRequest, plugin_root_url, modalCustomSmallStyles } from './../../utils/helper';
import ScheduleScan from './ScheduleScan';
import Reporting from './Reporting';
import PropTypes from 'prop-types';

const propTypes = {};

const defaultProps = {};

const BulkActions = (props) => {
	const [bulkAction, setBulkAction] = useState({});
	return (
		<>
			{props.bulkActionData.selectedCount > 0 && (
				<div className="btl-bulk-actions">
					<Select
						className="btl-select"
						classNamePrefix="btl-react-select"
						defaultValue={{ value: '', label: __('Bulk Actions', 'betterlinks-pro') }}
						options={[{ value: 'delete', label: __('Delete', 'betterlinks-pro') }]}
						onChange={(e) => setBulkAction(e)}
					/>
					<Button
						className="btl-select-button"
						isPrimary={true}
						onClick={() => {
							if (confirm(__('Are you sure you want to delete selected logs permanently?', 'betterlinks-pro'))) {
								rowDeleteHandler(props.bulkActionData.selectedRows, bulkAction, props.deleteHandler);
							}
						}}
					>
						{__('Apply', 'betterlinks-pro')}
					</Button>
				</div>
			)}
		</>
	);
};

const rowDeleteHandler = (selectedRows, action, deleteHandler) => {
	if (action.value === 'delete') {
		const IDs = selectedRows.reduce((acc, item) => {
			acc.push(item.ID);
			return acc;
		}, []);
		deleteHandler(IDs);
	}
};

const getBrokenLinks = (logs) => {
	const resutls = logs.reduce((acc, [key, value], index) => {
		if (value.status) {
			acc.push(value);
		}
		return acc;
	}, []);
	return resutls;
};

export default function BrokenLinks(props) {
	const [logModalIsOpen, setLogModalIsOpen] = useState(false);
	const [logModalContent, setLogModalContent] = useState('');
	const [removeLogID, setRemoveLogID] = useState(false);
	const [isResumeScan, setIsResumeScan] = useState(false);
	const [totalLinksData, setTotalLinksData] = useState([]);
	const [brokenLinksData, setBrokenLinksData] = useState([]);
	const [totalScanData, setTotalScanData] = useState([]);
	const [scanText, setScanText] = useState('Start Scanning');
	const [bulkActionData, setBulkActionData] = useState({});
	useEffect(() => {
		makeRequest({
			action: 'betterlinkspro/admin/get_broken_links_data',
		}).then((response) => {
			if (response.data.data) {
				const logs = Object.entries(JSON.parse(response.data.data.logs));
				const links = Object.entries(JSON.parse(response.data.data.links));
				setTotalLinksData(links);
				setTotalScanData(logs);
				setBrokenLinksData(getBrokenLinks(logs));
				if (logs.length > 0 && links.length > logs.length) {
					setIsResumeScan(true);
					setScanText(__('Resume Scan', 'betterlinks-pro'));
				}
			}
		});
	}, []);

	const onSelectedRowsChange = (e) => {
		setBulkActionData(e);
	};

	const freshScanHandler = () => {
		makeRequest({
			action: 'betterlinkspro/admin/delete_broken_link_checker_logs',
		}).then((response) => {
			setTotalScanData([]);
			setBrokenLinksData([]);
			instantScanHandler(true);
		});
	};

	const instantScanHandler = (isFresh = false) => {
		setScanText(__('Please Wait...', 'betterlinks-pro'));
		makeRequest({
			action: 'betterlinkspro/admin/run_instant_broken_link_checker',
		}).then((response) => {
			if (response.data.data) {
				const betterLinks = JSON.parse(response.data.data.links);
				var counter = 0;
				function recursively_ajax() {
					makeRequest({
						action: 'betterlinkspro/admin/run_broken_links_checker',
						...betterLinks[counter],
					}).then((response) => {
						const logs = Object.entries(JSON.parse(response.data.data));
						setTotalScanData(logs);
						setBrokenLinksData(getBrokenLinks(logs));
						counter++;
						if (counter <= betterLinks.length) {
							recursively_ajax();
						} else {
							setScanText(__('Start Scanning', 'betterlinks-pro'));
						}
					});
				}
				recursively_ajax();
			}
		});
	};

	const handleOnClickTestSingleBroken = (ID, setStartTesting) => {
		setStartTesting(true);
		makeRequest({
			action: 'betterlinkspro/admin/run_single_broken_link_checker',
			ID: ID,
		}).then((response) => {
			setStartTesting(false);
			if (response.data.success) {
				setRemoveLogID(ID);
			}
			setLogModalContent(response.data.data);
			setLogModalIsOpen(true);
		});
	};

	const handleMultiItemDelete = (IDs) => {
		makeRequest({
			action: 'betterlinkspro/admin/remove_multi_broken_link',
			...IDs,
		}).then((response) => {
			if (response.data.data) {
				const logs = Object.entries(JSON.parse(response.data.data));
				setTotalScanData(logs);
				setBrokenLinksData(getBrokenLinks(logs));
			}
		});
	};

	const handleOnClickDelete = (ID, short_url) => {
		makeRequest({
			action: 'betterlinkspro/admin/remove_broken_link',
			ID: ID,
		}).then((response) => {
			if (response.data.data) {
				const logs = Object.entries(JSON.parse(response.data.data));
				setTotalScanData(logs);
				setBrokenLinksData(getBrokenLinks(logs));
			}
		});
	};

	const handleOnClickUpdate = (ID, target_url) => {
		makeRequest({
			action: 'betterlinks/admin/update_link',
			ID,
			target_url,
			security: window.betterLinksGlobal.betterlinks_nonce,
		}).then((response) => {
			makeRequest({
				action: 'betterlinkspro/admin/update_broken_link',
				ID: ID,
				target_url: target_url,
			}).then((response) => {
				if (response.data.data) {
					setBrokenLinksData(getBrokenLinks(Object.entries(JSON.parse(response.data.data))));
				}
			});
		});
	};

	const columns = [
		{
			name: __('Link', 'betterlinks-pro'),
			selector: 'title',
			sortable: true,
		},
		{
			name: __('Short URL', 'betterlinks-pro'),
			selector: 'short_url',
			cell: (row) => {
				const [isCopyUrl, setCopyUrl] = useState(false);
				const copyShortUrl = (url) => {
					copyToClipboard(url);
					setCopyUrl(true);
					setTimeout(() => {
						setCopyUrl(false);
					}, 3000);
				};
				return (
					<div style={{ display: 'flex', alignItems: 'center' }}>
						<div className="btl-short-url-wrapper">
							<span className="btl-short-url">{site_url + '/' + row.short_url} </span>
							<button className="btl-short-url-copy-button btl-tooltip" onClick={() => copyShortUrl(site_url + '/' + row.short_url)}>
								<span className="icon">
									{isCopyUrl ? <span className="dashicons dashicons-yes"></span> : <img width="25" src={plugin_root_url + 'assets/images/copy-icon.svg'} />}
								</span>
								<span className="btl-tooltiptext">{__('Copy Link', 'betterlinks-pro')}</span>
							</button>
						</div>
					</div>
				);
			},
		},
		{
			name: __('Target URL', 'betterlinks-pro'),
			selector: 'target_url',
			cell: (row) => {
				const [isOpenEdit, setIsOpenEdit] = useState(false);
				const [targetURL, setTargetURL] = useState(row.target_url);
				return (
					<div className="btl-target-url">
						{isOpenEdit ? (
							<>
								<input type="text" value={targetURL} onChange={(e) => setTargetURL(e.target.value)} />
								<button className="button-secondary" onClick={() => handleOnClickUpdate(row.ID, targetURL)}>
									{__('Update', 'betterlinks-pro')}
								</button>
							</>
						) : (
							<>
								<span style={{ whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis', maxWidth: '230px' }}>{row.target_url}</span>
								<span className="edit-icon dashicons dashicons-edit" onClick={() => setIsOpenEdit(!isOpenEdit)}></span>
							</>
						)}
					</div>
				);
			},
		},
		{
			name: __('Action', 'betterlinks-pro'),
			selector: 'edit',
			cell: (row) => {
				const [startTesting, setStartTesting] = useState(false);
				return (
					<div className="btl-broken-link-table-action">
						<button
							className={`button-secondary btl-test-link-button ${startTesting ? 'btl-rotating' : ''}`}
							onClick={() => handleOnClickTestSingleBroken(row.ID, setStartTesting)}
						>
							<img src={plugin_root_url + 'assets/images/regenerate.svg'} alt="" />
						</button>
						<button
							className="button-secondary btl-delete-button"
							onClick={() => {
								if (confirm(__('Are you sure you want to delete log permanently?', 'betterlinks-pro'))) {
									handleOnClickDelete(row.ID, row.short_url);
								}
							}}
						>
							<i className="btl btl-delete"></i>
						</button>
					</div>
				);
			},
		},
	];

	const subHeaderComponentMemo = React.useMemo(() => {
		return (
			<>
				<BulkActions bulkActionData={bulkActionData} deleteHandler={handleMultiItemDelete} />
			</>
		);
	}, [bulkActionData, handleMultiItemDelete]);

	const closeLogModal = () => {
		setLogModalIsOpen(false);
		setRemoveLogID(false);
	};

	const removeBrokenLinkLog = () => {
		makeRequest({
			action: 'betterlinkspro/admin/remove_broken_link',
			ID: removeLogID,
		}).then((response) => {
			if (response.data.data) {
				const logs = Object.entries(JSON.parse(response.data.data));
				setTotalScanData(logs);
				setBrokenLinksData(getBrokenLinks(logs));
				closeLogModal();
			}
		});
	};

	return (
		<React.Fragment>
			<Modal isOpen={logModalIsOpen} onRequestClose={closeLogModal} style={modalCustomSmallStyles} ariaHideApp={false}>
				<span className="btl-close-modal" onClick={closeLogModal}>
					<i className="btl btl-cancel"></i>
				</span>
				<div className="btl-regenerate-modal">
					<div className="btl-icon">
						{removeLogID ? (
							<svg xmlns="http://www.w3.org/2000/svg" x="0" y="0" enableBackground="new 0 0 512 512" version="1.1" viewBox="0 0 512 512" xmlSpace="preserve" fill="#07c371">
								<path d="M497.36 69.995c-7.532-7.545-19.753-7.558-27.285-.032L238.582 300.845l-83.522-90.713c-7.217-7.834-19.419-8.342-27.266-1.126-7.841 7.217-8.343 19.425-1.126 27.266l97.126 105.481a19.273 19.273 0 0013.784 6.22c.141.006.277.006.412.006a19.317 19.317 0 0013.623-5.628L497.322 97.286c7.551-7.525 7.564-19.746.038-27.291z"></path>
								<path d="M492.703 236.703c-10.658 0-19.296 8.638-19.296 19.297 0 119.883-97.524 217.407-217.407 217.407-119.876 0-217.407-97.524-217.407-217.407 0-119.876 97.531-217.407 217.407-217.407 10.658 0 19.297-8.638 19.297-19.296C275.297 8.638 266.658 0 256 0 114.84 0 0 114.84 0 256c0 141.154 114.84 256 256 256 141.154 0 256-114.846 256-256 0-10.658-8.638-19.297-19.297-19.297z"></path>
							</svg>
						) : (
							<svg
								xmlns="http://www.w3.org/2000/svg"
								x="0"
								y="0"
								enableBackground="new 0 0 512.001 512.001"
								version="1.1"
								viewBox="0 0 512.001 512.001"
								xmlSpace="preserve"
								fill="#f34949"
							>
								<path d="M503.839 395.379l-195.7-338.962C297.257 37.569 277.766 26.315 256 26.315c-21.765 0-41.257 11.254-52.139 30.102L8.162 395.378c-10.883 18.85-10.883 41.356 0 60.205 10.883 18.849 30.373 30.102 52.139 30.102h391.398c21.765 0 41.256-11.254 52.14-30.101 10.883-18.85 10.883-41.356 0-60.205zm-25.978 45.207c-5.461 9.458-15.241 15.104-26.162 15.104H60.301c-10.922 0-20.702-5.646-26.162-15.104-5.46-9.458-5.46-20.75 0-30.208L229.84 71.416c5.46-9.458 15.24-15.104 26.161-15.104 10.92 0 20.701 5.646 26.161 15.104l195.7 338.962c5.459 9.458 5.459 20.75-.001 30.208z"></path>
								<path d="M241.001 176.01H270.997V325.99199999999996H241.001z"></path>
								<path d="M256 355.99c-11.027 0-19.998 8.971-19.998 19.998s8.971 19.998 19.998 19.998c11.026 0 19.998-8.971 19.998-19.998S267.027 355.99 256 355.99z"></path>
							</svg>
						)}
					</div>
					<h2>{logModalContent}</h2>
					{removeLogID && (
						<button className="btl-modal-submit-button" onClick={removeBrokenLinkLog}>
							{__('Remove Log', 'betterlinks-pro')}
						</button>
					)}
				</div>
			</Modal>
			<div className="btl-tab-panel-inner btl-broken-links-panel">
				<div className="btl-broken-link-checker-wrapper">
					<div className="btl-broken-link-checker">
						<ScheduleScan />
						<h3 style={{ marginTop: '20px' }}>{__('Instant Scan', 'betterlinks-pro')}</h3>
						<div style={{ display: 'flex' }}>
							<button onClick={() => instantScanHandler(false)} style={{ marginRight: '15px' }}>
								{scanText}
							</button>
							{isResumeScan && <button onClick={freshScanHandler}>{__('Start New Scan', 'betterlinks-pro')}</button>}
							{totalLinksData.length > 0 && totalScanData.length > 0 && totalLinksData.length == totalScanData.length && (
								<p style={{ marginLeft: '15px', display: 'flex', justifyContent: 'center', alignItems: 'center', color: '#58CD79' }}>
									<img src={plugin_root_url + 'assets/images/checkmark.svg'} alt="" style={{ marginRight: '5px' }} /> <strong>{__('Scan is Complete.', 'betterlinks-pro')}</strong>
								</p>
							)}
						</div>
						<div className="btl-scan-outputs">
							<div className="btl-scan-output">
								<span className="icon">
									<img src={plugin_root_url + 'assets/images/links.svg'} alt="" />
								</span>
								<h4 className="count">{totalLinksData.length}</h4>
								<p className="title">{__('Total Links', 'betterlinks-pro')}</p>
							</div>
							<div className="btl-scan-output">
								<span className="icon">
									<img src={plugin_root_url + 'assets/images/scan.svg'} alt="" />
								</span>
								<h4 className="count">{totalScanData.length}</h4>
								<p className="title">{__('Links Scanned', 'betterlinks-pro')}</p>
							</div>
							<div className="btl-scan-output">
								<span className="icon">
									<img src={plugin_root_url + 'assets/images/error.svg'} alt="" />
								</span>
								<h4 className="count">{brokenLinksData.length}</h4>
								<p className="title">{__(' Broken Links Found', 'betterlinks-pro')}</p>
							</div>
						</div>
					</div>
					<div className="btl-broken-link-checker">
						<Reporting />
					</div>
				</div>
			</div>
			<div className="btl-broken-links-table-wrapper">
				<DataTable
					className="btl-broken-links-table"
					title={__('Broken Link Reports', 'betterlinks-pro')}
					columns={columns}
					data={brokenLinksData}
					pagination
					subHeader
					subHeaderComponent={subHeaderComponentMemo}
					selectableRows
					persistTableHead
					onSelectedRowsChange={(e) => onSelectedRowsChange(e)}
				/>
			</div>
		</React.Fragment>
	);
}

BrokenLinks.propTypes = propTypes;
BrokenLinks.defaultProps = defaultProps;
