import React from 'react';
import ShareUrl from 'share-url';
import queryString from 'query-string';
import { __ } from '@wordpress/i18n';
import PropTypes from 'prop-types';
import Twitter from './Twitter';
import Linkedin from './Linkedin';
import Email from './Email';
import Reddit from './Reddit';
import Pinterest from './Pinterest';
import { plugin_root_url } from './../../utils/helper';

const propTypes = {};

const defaultProps = {};

export default class BuiltInUTMBuilder extends React.Component {
	constructor(props) {
		super(props);
		this.state = {
			platform: '',
			temp_target_url: this.props.targetUrl,
		};
		this.selectSocialMediaHandler = this.selectSocialMediaHandler.bind(this);
		this.saveTargetURLHandler = this.saveTargetURLHandler.bind(this);
		this.saveTempValueHandler = this.saveTempValueHandler.bind(this);
	}

	componentDidMount() {
		if (this.props.targetUrl.match(/facebook.com/i)) {
			this.setState({ platform: 'facebook' });
		} else if (this.props.targetUrl.match(/twitter.com/i)) {
			this.setState({ platform: 'twitter' });
		} else if (this.props.targetUrl.match(/linkedin.com/i)) {
			this.setState({ platform: 'linkedin' });
		} else if (this.props.targetUrl.match(/mailto/i)) {
			this.setState({ platform: 'email' });
		} else if (this.props.targetUrl.match(/reddit.com/i)) {
			this.setState({ platform: 'reddit' });
		} else if (this.props.targetUrl.match(/pinterest.com/i)) {
			this.setState({ platform: 'pinterest' });
		}
	}

	selectSocialMediaHandler(e) {
		this.setState({ platform: e.target.value });
		if (e.target.value == 'facebook') {
			const parsed = queryString.parseUrl(this.props.targetUrl);
			const url = parsed.query.u ? parsed.query.u : parsed.query.url;
			this.setState({ temp_target_url: ShareUrl.facebook({ u: url ? url : this.props.targetUrl }) });
		} else if (e.target.value == 'twitter') {
			this.setState({ temp_target_url: this.props.targetUrl });
		} else if (e.target.value == 'linkedin') {
			this.setState({ temp_target_url: this.props.targetUrl });
		} else if (e.target.value == 'pinterest') {
			this.setState({ temp_target_url: this.props.targetUrl });
		} else if (e.target.value == 'reddit') {
			this.setState({ temp_target_url: this.props.targetUrl });
		}
	}

	saveTempValueHandler(url) {
		this.setState({ temp_target_url: url });
	}

	saveTargetURLHandler() {
		this.props.setFieldValue('target_url', this.state.temp_target_url);
		this.props.closeUTMModal();
	}

	render() {
		return (
			<React.Fragment>
				<div className="btl-modal-utm-builder">
					<h3 className="btl-modal-utm-builder__title">{__('Social Share', 'betterlinks-pro')}</h3>
					<div className="btl-modal-utm-builder__body">
						<div className="btl-modal-utm-builder__form-group btl-modal-utm-templates">
							<label htmlFor="socialmedia">{__('Social Media', 'betterlinks-pro')}</label>
							<div id="socialmedia">
								<label>
									<input type="radio" name="platform" value="facebook" onChange={this.selectSocialMediaHandler} checked={this.state.platform === 'facebook'} />
									<img src={plugin_root_url + 'assets/images/facebook.svg'} alt={__('Facebook', 'betterlinks-pro')} /> {__('Facebook', 'betterlinks-pro')}
								</label>
								<label>
									<input type="radio" name="platform" value="twitter" onChange={this.selectSocialMediaHandler} checked={this.state.platform === 'twitter'} />
									<img src={plugin_root_url + 'assets/images/twitter.svg'} alt={__('Twitter', 'betterlinks-pro')} /> {__('Twitter', 'betterlinks-pro')}
								</label>
								<label>
									<input type="radio" name="platform" value="linkedin" onChange={this.selectSocialMediaHandler} checked={this.state.platform === 'linkedin'} />
									<img src={plugin_root_url + 'assets/images/linkedin.svg'} alt={__('Linkedin', 'betterlinks-pro')} /> {__('Linkedin', 'betterlinks-pro')}
								</label>
								<label>
									<input type="radio" name="platform" value="email" onChange={this.selectSocialMediaHandler} checked={this.state.platform === 'email'} />
									<img src={plugin_root_url + 'assets/images/email.svg'} alt={__('Email', 'betterlinks-pro')} /> {__('Email', 'betterlinks-pro')}
								</label>
								<label>
									<input type="radio" name="platform" value="reddit" onChange={this.selectSocialMediaHandler} checked={this.state.platform === 'reddit'} />
									<img src={plugin_root_url + 'assets/images/reddit.svg'} alt={__('Reddit', 'betterlinks-pro')} /> {__('Reddit', 'betterlinks-pro')}
								</label>
								<label>
									<input type="radio" name="platform" value="pinterest" onChange={this.selectSocialMediaHandler} checked={this.state.platform === 'pinterest'} />
									<img src={plugin_root_url + 'assets/images/pinterest.svg'} alt={__('Pinterest', 'betterlinks-pro')} /> {__('Pinterest', 'betterlinks-pro')}
								</label>
							</div>
						</div>
						{this.state.platform == 'twitter' && <Twitter targetUrl={this.props.targetUrl} saveTempValueHandler={this.saveTempValueHandler} />}
						{this.state.platform == 'linkedin' && <Linkedin targetUrl={this.props.targetUrl} saveTempValueHandler={this.saveTempValueHandler} />}
						{this.state.platform == 'email' && <Email targetUrl={this.props.targetUrl} saveTempValueHandler={this.saveTempValueHandler} />}
						{this.state.platform == 'reddit' && <Reddit targetUrl={this.props.targetUrl} saveTempValueHandler={this.saveTempValueHandler} />}
						{this.state.platform == 'pinterest' && <Pinterest targetUrl={this.props.targetUrl} saveTempValueHandler={this.saveTempValueHandler} />}
						<div className="btl-modal-utm-builder__form-group">
							<label htmlFor="socialmedia">{__('Social Media Share', 'betterlinks-pro')}</label>
							<div>
								<textarea rows="3" name="temp_target_url" value={this.state.temp_target_url} onChange={(e) => this.setState({ temp_target_url: e.target.value })} />
							</div>
						</div>
						<div className="btl-modal-utm-builder__form-group">
							<button type="button" onClick={this.saveTargetURLHandler}>
								{__('Save', 'betterlinks-pro')}
							</button>
						</div>
					</div>
				</div>
			</React.Fragment>
		);
	}
}

BuiltInUTMBuilder.propTypes = propTypes;
BuiltInUTMBuilder.defaultProps = defaultProps;
