import React from 'react';
import { __ } from '@wordpress/i18n';
import Modal from 'react-modal';
import Select from 'react-select';
import { Rotation, Geographic, Technology, Time } from '..';

const propTypes = {};

const defaultProps = {};

const customStyles = {
	overlay: {
		background: 'rgba(35, 40, 45, 0.62)',
	},
	content: {
		top: '50%',
		left: '50%',
		right: 'auto',
		bottom: 'auto',
		maxWidth: '800px',
		marginRight: '-50%',
		transform: 'translate(-50%, -50%)',
	},
};

export default function DynamicRedirect(props) {
	const { dynamic_redirect, target_url } = props.values;
	const { type, value, extra } = dynamic_redirect;

	const dynamicRedirect = [
		{
			value: 'rotation',
			label: (
				<span className="btl-option-with-icon">
					<span className="btl btl-reload"></span> {__('Rotation', 'betterlinks-pro')}
				</span>
			),
		},
		{
			value: 'geographic',
			label: (
				<span className="btl-option-with-icon">
					<span className="btl btl-geography"></span> {__('Geography', 'betterlinks-pro')}
				</span>
			),
		},
		{
			value: 'technology',
			label: (
				<span className="btl-option-with-icon">
					<span className="btl btl-device"></span> {__('Device', 'betterlinks-pro')}
				</span>
			),
		},
		{
			value: 'time',
			label: (
				<span className="btl-option-with-icon">
					<span className="btl btl-calendar"></span> {__('Time', 'betterlinks-pro')}
				</span>
			),
		},
	];

	const [modalIsOpen, setIsOpen] = React.useState(false);

	function openModal() {
		setIsOpen(true);
	}

	function afterOpenModal() {
		if (!type) {
			props.setFieldValue('track_me', true);
		}
	}

	function closeModal() {
		if (type == 'rotation') {
			props.setFieldValue('dynamic_redirect.type', 'none');
		}
		setIsOpen(false);
	}

	function savedAndCloseModal() {
		if (type === 'rotation' && extra.rotation_mode === 'weighted') {
			let isEmptyField = false;
			const weight = value.reduce((acc, item) => {
				if (!item.link) {
					isEmptyField = true;
				}
				return acc + item.weight;
			}, 0);
			if (weight === 100 && !isEmptyField) {
				setIsOpen(false);
			} else if (isEmptyField) {
				alert(__("Rotation URLs can't be blank", 'betterlinks-pro'));
			} else {
				alert(__('Your Rotation URLs must add up to 100% in total', 'betterlinks-pro'));
			}
		} else if (type === 'technology') {
			let isEmptyField = false;
			value.map((item, index) => {
				if (!item.link) {
					isEmptyField = true;
				}
			});
			if (!isEmptyField) {
				setIsOpen(false);
			} else if (isEmptyField) {
				alert(__("Technology URLs can't be blank", 'betterlinks-pro'));
			}
		} else if (type === 'geographic') {
			let isEmptyTargetURL = false;
			let isEmptyCountry = false;
			value.map((item, index) => {
				if (!item.link) {
					isEmptyTargetURL = true;
				}
				if (!item.country) {
					isEmptyCountry = true;
				}
			});
			if (!isEmptyTargetURL && !isEmptyCountry) {
				setIsOpen(false);
			} else if (isEmptyTargetURL) {
				alert(__("Geographic URLs can't be blank", 'betterlinks-pro'));
			} else if (isEmptyCountry) {
				alert(__("Geographic Country can't be blank", 'betterlinks-pro'));
			}
		} else if (type === 'time') {
			let isEmptyTarget = false;
			let isDateError = false;
			let isEmptyDate = false;
			value.map((item, index) => {
				if (!item.link) {
					isEmptyTarget = true;
				}
				if (item.start_date && item.end_date && item.start_date > item.end_date) {
					isDateError = true;
				} else if (!item.start_date || !item.end_date) {
					isEmptyDate = true;
				}
			});
			if (!isEmptyTarget) {
				if (!isEmptyDate && !isDateError) {
					setIsOpen(false);
				}
				if (isDateError) {
					alert(__('Your Time Period Redirect start time must come before the end time.', 'betterlinks-pro'));
				} else if (isEmptyDate) {
					alert(__("Start date or End date can't be blank", 'betterlinks-pro'));
				}
			} else if (isEmptyTarget) {
				alert(__("Time Redirect URLs can't be blank", 'betterlinks-pro'));
			}
		} else {
			setIsOpen(false);
		}
	}

	return (
		<React.Fragment>
			<div className="link-options-info">
				<ul>
					<li>
						<strong className="btl-redirection-label btl-redirection-label-large">{__('Redirection Type:', 'betterlinks-pro')}</strong>
						{type && type != 'none' ? type : 'Disabled'}
					</li>
					{extra && type == 'rotation' && extra.rotation_mode && (
						<li>
							<strong className="btl-redirection-label btl-redirection-label-large">{__('Redirection Mode:', 'betterlinks-pro')}</strong>
							{type && type != 'none' ? extra.rotation_mode : 'Disabled'}
						</li>
					)}
					{value.length > 0 ? (
						value.map((item, index) => (
							<li>
								<strong className="btl-redirection-label">
									{__('Target URL', 'betterlinks-pro')} {index + 1 + ':'}
								</strong>
								<input type="text" value={item.link} disabled />
							</li>
						))
					) : (
						<>
							<li>
								<strong className="btl-redirection-label">{__('Target URL 1', 'betterlinks-pro')}</strong>
								<input type="text" value="example-1.com" disabled />
							</li>
							<li>
								<strong className="btl-redirection-label">{__('Target URL 2', 'betterlinks-pro')}</strong>
								<input type="text" value="example-2.com" disabled />
							</li>
						</>
					)}
					<li>
						<strong className="btl-redirection-label"></strong>
						<button className="btl-add-link-button" type="button" onClick={openModal}>
							<span className="icon">
								<span className="btl btl-add"></span>
							</span>
							<span className="text">{__('Add New Link', 'betterlinks-pro')}</span>
						</button>
					</li>
				</ul>
				<p className="btl-block-code">
					{__('This will allow to create Rotation URLs and run A/B Split testing. To configure this', 'betterlinks-pro')}
					<button className="btl-filled-button" type="button" onClick={openModal}>
						{__('Click Here', 'betterlinks-pro')}
					</button>
				</p>
			</div>
			<Modal isOpen={modalIsOpen} onAfterOpen={afterOpenModal} style={customStyles} ariaHideApp={false}>
				<span className="btl-close-modal" onClick={closeModal}>
					<i className="btl btl-cancel"></i>
				</span>
				<div className="link-modal-options__dynamic-redirects">
					<div className="btl-modal-form-group">
						<label className="btl-modal-form-label">
							<label className="btl-modal-form-label">{__('Enable Dynamic Redirect', 'betterlinks-pro')}</label>
							<input
								style={{ marginTop: 0 }}
								type="checkbox"
								onChange={() =>
									props.setFieldValue('dynamic_redirect.type', type == 'rotation' || type == 'geographic' || type == 'technology' || type == 'time' ? 'none' : 'rotation')
								}
								checked={type == 'rotation' || type == 'geographic' || type == 'technology' || type == 'time'}
							/>
						</label>
					</div>
					{type && type != 'none' && (
						<div className="btl-modal-form-group">
							<label className="btl-modal-form-label">{__('Redirection Type', 'betterlinks-pro')}</label>
							<Select
								openOnFocus={true}
								className="btl-modal-select--full"
								classNamePrefix="btl-react-select"
								defaultValue={dynamicRedirect.filter((item, index) => item.value == type)}
								value={dynamicRedirect.filter((item, index) => item.value == type)}
								options={dynamicRedirect}
								onChange={(option) => {
									props.setFieldValue('dynamic_redirect.type', option.value);
								}}
								isSearchable={false}
							/>
						</div>
					)}
					{type == 'rotation' && <Rotation value={value} extra={extra} target_url={target_url} setFieldValue={props.setFieldValue} />}
					{type == 'geographic' && <Geographic value={value} extra={extra} setFieldValue={props.setFieldValue} />}
					{type == 'technology' && <Technology value={value} extra={extra} setFieldValue={props.setFieldValue} />}
					{type == 'time' && <Time value={value} extra={extra} setFieldValue={props.setFieldValue} />}
					<div className="btl-modal-form-group">
						<label className="btl-modal-form-label"></label>
						<button type="button" onClick={savedAndCloseModal} className="btl-modal-submit-button">
							{__('Save & Close', 'betterlinks-pro')}
						</button>
					</div>
				</div>
			</Modal>
		</React.Fragment>
	);
}

DynamicRedirect.propTypes = propTypes;
DynamicRedirect.defaultProps = defaultProps;
