import React, { useState, useEffect } from 'react';
import { __ } from '@wordpress/i18n';
import Select from 'react-select';
import country from './../../../assets/vendor/country.json';
import PropTypes from 'prop-types';

const propTypes = {};

const defaultProps = {};

export default function Geographic(props) {
	const [countryList, setCountryList] = useState(false);
	const { value, setFieldValue } = props;

	useEffect(() => {
		setCountryList(
			Object.entries(country).reduce((acc, [value, label]) => {
				acc.push({ label, value });
				return acc;
			}, [])
		);
	}, []);

	return (
		<React.Fragment>
			<div className="btl-modal-form-group">
				<label className="btl-modal-form-label" style={{ paddingBottom: 0 }}>
					{__('Geographic Target URLs', 'betterlinks-pro')}
				</label>
			</div>
			<div>
				{value.length > 0 &&
					value.map((item, index) => (
						<div className="btl-modal-form-group">
							<div className="btl-modal-form-label btl-small-label">
								{__('Target URL', 'betterlinks-pro')} {index + 1}
							</div>
							<div className="btl-modal-form-data-wrapper btl-geographic-form-data-wrapper">
								{countryList && (
									<Select
										className="btl-modal-select--full btl-modal-select--full--auto"
										classNamePrefix="btl-react-select-auto"
										defaultValue={countryList.filter((country, index) => {
											if (Array.isArray(item.country)) {
												return item.country.includes(country.value);
											}
										})}
										onChange={(link) =>
											setFieldValue(
												`dynamic_redirect.value.${index}.country`,
												link.reduce((acc, link, index) => {
													acc.push(link.value);
													return acc;
												}, [])
											)
										}
										options={countryList}
										placeholder={__('Select Country', 'betterlinks-pro')}
										isClearable={false}
										isMulti={true}
									/>
								)}
								<label className="btl-modal-url-select">
									<input
										className="btl-modal-form-control"
										type="text"
										value={item.link}
										onChange={(e) => setFieldValue(`dynamic_redirect.value.${index}.link`, e.target.value.replace(/\s+/g, ''))}
									/>
								</label>
								<button
									type="button"
									className="btl-delete-button"
									onClick={() =>
										setFieldValue(
											'dynamic_redirect.value',
											value.filter((item, itemIndex) => itemIndex != index)
										)
									}
								>
									<span className="dashicons dashicons-trash"></span>
								</button>
							</div>
						</div>
					))}
				<div className="btl-modal-form-group">
					<div className="btl-modal-form-label btl-small-label"></div>
					<button className="btl-add-link-button" type="button" onClick={() => setFieldValue('dynamic_redirect.value', [...value, { country: '', link: '' }])}>
						<span className="icon">
							<span className="btl btl-add"></span>
						</span>
						<span className="text">{__('Add New Link', 'betterlinks-pro')}</span>
					</button>
				</div>
			</div>
		</React.Fragment>
	);
}

Geographic.propTypes = propTypes;
Geographic.defaultProps = defaultProps;
