import React from 'react';
import PropTypes from 'prop-types';
import axios from 'axios';
import { __ } from '@wordpress/i18n';
import { nonce, plugin_root_url } from './../../utils/helper';

const propTypes = {};

const defaultProps = {};

export default class License extends React.Component {
	constructor(props) {
		super(props);
		this.state = {
			status: localStorage.getItem('betterlinks_pro_is_valid'),
			key: '',
			tempKey: localStorage.getItem('betterlinks_pro_temp_key'),
			isRequestSending: false,
			isDisable: false,
			errorMessage: '',
		};
	}

	componentDidMount() {
		if (localStorage.getItem('betterlinks_pro_is_valid') != 'valid') {
			axios.post(`${ajaxurl}?action=betterlinkspro/admin/get_license&security=${nonce}`).then(
				(response) => {
					localStorage.setItem('betterlinks_pro_is_valid', response.data.data.status);
					localStorage.setItem('betterlinks_pro_temp_key', response.data.data.key);
					this.setState({ status: response.data.data.status, tempKey: response.data.data.key });
				},
				(error) => {
					console.log(error);
				}
			);
		}
	}
	activeLicense() {
		this.setState({ isDisable: true, isRequestSending: true });
		let form_data = new FormData();
		form_data.append('action', 'betterlinkspro/admin/activate_license');
		form_data.append('security', nonce);
		form_data.append('betterlinks-pro-license-key', this.state.key);
		axios.post(ajaxurl, form_data).then(
			(response) => {
				if (response.data) {
					if (response.data.success) {
						localStorage.setItem('betterlinks_pro_is_valid', response.data.data.status);
						localStorage.setItem('betterlinks_pro_temp_key', response.data.data.key);
						this.setState({ status: response.data.data.status, tempKey: response.data.data.key, isDisable: false, isRequestSending: false });
					} else {
						this.setState({ errorMessage: response.data.data, isDisable: false, isRequestSending: false });
					}
				}
			},
			(error) => {
				console.log(error);
			}
		);
	}

	deactiveLicense() {
		this.setState({ isDisable: true, isRequestSending: true });
		let form_data = new FormData();
		form_data.append('action', 'betterlinkspro/admin/deactivate_license');
		form_data.append('security', nonce);
		axios.post(ajaxurl, form_data).then(
			(response) => {
				if (response.data) {
					localStorage.removeItem('betterlinks_pro_is_valid');
					localStorage.removeItem('betterlinks_pro_temp_key');
					this.setState({ status: false, tempKey: '', key: '', isDisable: false, isRequestSending: false });
				}
			},
			(error) => {
				console.log(error);
			}
		);
	}
	render() {
		return (
			<React.Fragment>
				<div className="btl-tab-inner-divider">
					<div className="btl-tab-panel-inner">
						<div className="btl-license-container">
							{this.state.status == 'valid' ? (
								<div className="btl-validated-feature-list">
									<div className="validated-feature-list-item">
										<div className="validated-feature-list-icon">
											<span className="dashicons dashicons-yes-alt"></span>
										</div>
										<div className="validated-feature-list-content">
											<h4>{__('Auto Update', 'betterlinks-pro')}</h4>
											<p>{__('Update the plugin right from your WordPress Dashboard.', 'betterlinks-pro')}</p>
										</div>
									</div>
									<div className="validated-feature-list-item">
										<div className="validated-feature-list-icon">
											<span className="dashicons dashicons-yes-alt"></span>
										</div>
										<div className="validated-feature-list-content">
											<h4>{__('Premium Support', 'betterlinks-pro')}</h4>
											<p>{__('Supported by professional and courteous staff.', 'betterlinks-pro')}</p>
										</div>
									</div>
								</div>
							) : (
								<React.Fragment>
									<div className="btl-lockscreen">
										<div className="btl-lockscreen-icons">
											<img src={plugin_root_url + 'assets/images/lock.svg'} alt="icon" />
											<img src={plugin_root_url + 'assets/images/arrow-right.svg'} alt="icon" />
											<img src={plugin_root_url + 'assets/images/key.svg'} alt="icon" />
											<img src={plugin_root_url + 'assets/images/arrow-right.svg'} alt="icon" />
											<img src={plugin_root_url + 'assets/images/lock-open.svg'} alt="icon" />
										</div>
										<h1>{__('Just one more step to go!', 'betterlinks-pro')}</h1>
									</div>
									<div className="btl-license-instruction">
										<p>
											{__('Enter your license key here, to activate', 'betterlinks-pro')} <strong>{__('BetterLinks Pro', 'betterlinks-pro')}</strong>
											{__(', and get automatic updates and premium support.', 'betterlinks-pro')}
										</p>
										<p>
											{__('Visit the ', 'betterlinks-pro')}
											<a href="" target="_blank">
												{__('Validation Guide', 'betterlinks-pro')}
											</a>
											{__(' for help.', 'betterlinks-pro')}
										</p>

										<ol>
											<li>
												{__('Log in to ', 'betterlinks-pro')}
												<a href="https://wpdeveloper.com/account/" target="_blank">
													{__('your account', 'betterlinks-pro')}
												</a>
												{__(' to get your license key.', 'betterlinks-pro')}
											</li>
											<li>
												{__("If you don't yet have a license key, get ", 'betterlinks-pro')}
												<a href="#" target="_blank">
													{__('BetterLinks Pro now', 'betterlinks-pro')}
												</a>
											</li>
											<li>{__('Copy the license key from your account and paste it below.', 'betterlinks-pro')}</li>
											<li>
												{__('Click on ', 'betterlinks-pro')}
												<strong>{__('"Activate License"', 'betterlinks-pro')}</strong> {__('button.', 'betterlinks-pro')}
											</li>
										</ol>
									</div>
								</React.Fragment>
							)}
							<div className="btl-license-input-group">
								<div className="btl-license-input">
									{this.state.status == 'valid' ? (
										<input placeholder={__('Place Your License Key and Activate', 'betterlinks-pro')} value={this.state.tempKey} disabled="disabled" />
									) : (
										<input
											placeholder={__('Place Your License Key and Activate', 'betterlinks-pro')}
											value={this.state.key}
											onChange={(e) => this.setState({ key: e.target.value })}
										/>
									)}
								</div>
								<div className="btl-license-buttons">
									{this.state.status == 'valid' ? (
										<button
											id="submit"
											type="button"
											className="btl-btn-license btl-btn-license--deactivation"
											onClick={() => this.deactiveLicense()}
											disabled={this.state.isDisable}
										>
											{this.state.isRequestSending ? __('Deactivating...', 'betterlinks-pro') : __('Deactivate License', 'betterlinks-pro')}
										</button>
									) : (
										<button id="submit" type="button" className="btl-btn-license btl-btn-license--activation" onClick={() => this.activeLicense()} disabled={this.state.isDisable}>
											{this.state.isRequestSending ? __('Activating...', 'betterlinks-pro') : __('Activate License', 'betterlinks-pro')}
										</button>
									)}
								</div>
							</div>
						</div>
						<p className="error-message">{this.state.errorMessage}</p>
					</div>
				</div>
			</React.Fragment>
		);
	}
}

License.propTypes = propTypes;
License.defaultProps = defaultProps;
