import React from 'react';
import axios from 'axios';
import { __ } from '@wordpress/i18n';
import { betterlinkspro_nonce, roles, delayStatusChanged } from './../../utils/helper';

const propTypes = {};

const defaultProps = {};

export default class RoleManagement extends React.Component {
	constructor(props) {
		super(props);
		this.state = {
			submitLabel: __('Save Settings', 'betterlinks-pro'),
			viewlinks: [],
			writelinks: [],
			editlinks: [],
			checkanalytics: [],
			editsettings: [],
			editFavorite: [],
		};
		this.handleSubmit = this.handleSubmit.bind(this);
		this.onChangeViewLinks = this.onChangeViewLinks.bind(this);
		this.onChangeWriteLinks = this.onChangeWriteLinks.bind(this);
		this.onChangeEditLinks = this.onChangeEditLinks.bind(this);
		this.onChangeAnalytic = this.onChangeAnalytic.bind(this);
		this.onChangeEditSettings = this.onChangeEditSettings.bind(this);
		this.onChangeEditFavorite = this.onChangeEditFavorite.bind(this);
		this.changeSubmitLabel = this.changeSubmitLabel.bind(this);
	}

	componentDidMount() {
		let form_data = new FormData();
		form_data.append('action', 'betterlinkspro/admin/get_role_management');
		form_data.append('security', betterlinkspro_nonce);
		axios.post(window.ajaxurl, form_data).then(
			(response) => {
				if (response.data) {
					this.setState({ ...response.data.data });
				}
			},
			(error) => {
				console.log(error);
			}
		);
	}

	changeSubmitLabel(newLabel) {
		this.setState({ submitLabel: newLabel });
	}

	handleSubmit(e) {
		e.preventDefault();
		delayStatusChanged(__('Saving...', 'betterlinks-pro'), __('Saved!', 'betterlinks-pro'), __('Save Settings', 'betterlinks-pro'), this.changeSubmitLabel);
		let form_data = new FormData();
		let roleData = window.jQuery('#rolemanagement').serializeArray();
		form_data.append('action', 'betterlinkspro/admin/role_management');
		form_data.append('security', betterlinkspro_nonce);
		form_data.append(
			'viewlinks',
			roleData.reduce((accumulator, item) => {
				if (item.name == 'viewlinks') {
					accumulator.push(item.value);
				}
				return accumulator;
			}, [])
		);
		form_data.append(
			'writelinks',
			roleData.reduce((accumulator, item) => {
				if (item.name == 'writelinks') {
					accumulator.push(item.value);
				}
				return accumulator;
			}, [])
		);
		form_data.append(
			'editlinks',
			roleData.reduce((accumulator, item) => {
				if (item.name == 'editlinks') {
					accumulator.push(item.value);
				}
				return accumulator;
			}, [])
		);
		form_data.append(
			'checkanalytics',
			roleData.reduce((accumulator, item) => {
				if (item.name == 'checkanalytics') {
					accumulator.push(item.value);
				}
				return accumulator;
			}, [])
		);
		form_data.append(
			'editsettings',
			roleData.reduce((accumulator, item) => {
				if (item.name == 'editsettings') {
					accumulator.push(item.value);
				}
				return accumulator;
			}, [])
		);
		form_data.append(
			'editFavorite',
			roleData.reduce((accumulator, item) => {
				if (item.name == 'editFavorite') {
					accumulator.push(item.value);
				}
				return accumulator;
			}, [])
		);
		axios.post(window.ajaxurl, form_data).then(
			() => {},
			(error) => {
				console.log(error);
			}
		);
	}

	onChangeViewLinks(status, key) {
		if (status == true) {
			this.setState({
				viewlinks: this.state.viewlinks.filter((item) => item != key),
			});
		} else {
			this.setState({ viewlinks: [...this.state.viewlinks, key] });
		}
	}
	onChangeWriteLinks(status, key) {
		if (status == true) {
			this.setState({
				writelinks: this.state.writelinks.filter((item) => item != key),
			});
		} else {
			this.setState({ writelinks: [...this.state.writelinks, key] });
		}
	}

	onChangeEditLinks(status, key) {
		if (status == true) {
			this.setState({
				editlinks: this.state.editlinks.filter((item) => item != key),
			});
		} else {
			this.setState({ editlinks: [...this.state.editlinks, key] });
		}
	}

	onChangeAnalytic(status, key) {
		if (status == true) {
			this.setState({
				checkanalytics: this.state.checkanalytics.filter((item) => item != key),
			});
		} else {
			this.setState({ checkanalytics: [...this.state.checkanalytics, key] });
		}
	}

	onChangeEditSettings(status, key) {
		if (status == true) {
			this.setState({
				editsettings: this.state.editsettings.filter((item) => item != key),
			});
		} else {
			this.setState({ editsettings: [...this.state.editsettings, key] });
		}
	}

	onChangeEditFavorite(status, key) {
		if (status == true) {
			this.setState({
				editFavorite: this.state.editFavorite.filter((item) => item != key),
			});
		} else {
			this.setState({ editFavorite: [...this.state.editFavorite, key] });
		}
	}

	render() {
		return (
			<React.Fragment>
				<div className="btl-tab-inner-divider-2">
					<div className="btl-tab-panel-inner">
						<div className="btl-role-container">
							<form className="form" onSubmit={this.handleSubmit} id="rolemanagement">
								<div className="btl-role-item btl-form-group">
									<label className="btl-form-label">{__('Who Can View Links?', 'betterlinks-pro')}</label>
									<div className="writelinks link-options__body">
										{Object.entries(roles).map(([key, value], index) => (
											<label htmlFor={`viewlinks_${index}`} key={`viewlinks_${index}`} className="btl-checkbox-field block">
												<input
													id={`viewlinks_${index}`}
													type="checkbox"
													name="viewlinks"
													className="btl-check"
													value={key}
													checked={this.state.viewlinks && this.state.viewlinks.includes(key)}
													onChange={() => this.onChangeViewLinks(this.state.viewlinks && this.state.viewlinks.includes(key), key)}
												/>{' '}
												<span className="text">{value}</span>
											</label>
										))}
									</div>
								</div>
								<div className="btl-role-item btl-form-group">
									<label className="btl-form-label">{__('Who Can Create Links?', 'betterlinks-pro')}</label>
									<div className="writelinks link-options__body">
										{Object.entries(roles).map(([key, value], index) => (
											<label htmlFor={`writelinks_${index}`} key={`writelinks_${index}`} className="btl-checkbox-field block">
												<input
													id={`writelinks_${index}`}
													type="checkbox"
													name="writelinks"
													className="btl-check"
													value={key}
													checked={this.state.writelinks && this.state.writelinks.includes(key)}
													onChange={() => this.onChangeWriteLinks(this.state.writelinks && this.state.writelinks.includes(key), key)}
												/>{' '}
												<span className="text">{value}</span>
											</label>
										))}
									</div>
								</div>
								<div className="btl-role-item btl-form-group">
									<label className="btl-form-label">{__('Who Can Edit Links?', 'betterlinks-pro')}</label>
									<div className="editlinks link-options__body">
										{Object.entries(roles).map(([key, value], index) => (
											<label htmlFor={`editlinks_${index}`} key={`editlinks_${index}`} className="btl-checkbox-field block">
												<input
													id={`editlinks_${index}`}
													type="checkbox"
													name="editlinks"
													className="btl-check"
													value={key}
													checked={this.state.editlinks && this.state.editlinks.includes(key)}
													onChange={() => this.onChangeEditLinks(this.state.editlinks && this.state.editlinks.includes(key), key)}
												/>{' '}
												<span className="text">{value}</span>
											</label>
										))}
									</div>
								</div>
								<div className="btl-role-item btl-form-group">
									<label className="btl-form-label">{__('Who Can Check Analytics?', 'betterlinks-pro')}</label>
									<div className="checkanalytics link-options__body">
										{Object.entries(roles).map(([key, value], index) => (
											<label htmlFor={`checkanalytics_${index}`} key={`checkanalytics_${index}`} className="btl-checkbox-field block">
												<input
													id={`checkanalytics_${index}`}
													type="checkbox"
													name="checkanalytics"
													className="btl-check"
													value={key}
													checked={this.state.checkanalytics && this.state.checkanalytics.includes(key)}
													onChange={() => this.onChangeAnalytic(this.state.checkanalytics && this.state.checkanalytics.includes(key), key)}
												/>{' '}
												<span className="text">{value}</span>
											</label>
										))}
									</div>
								</div>
								<div className="btl-role-item btl-form-group">
									<label className="btl-form-label">{__('Who Can Edit Settings?', 'betterlinks-pro')}</label>
									<div className="checkanalytics link-options__body">
										{Object.entries(roles).map(([key, value], index) => (
											<label htmlFor={`editsettings_${index}`} key={`editsettings_${index}`} className="btl-checkbox-field block">
												<input
													id={`editsettings_${index}`}
													type="checkbox"
													name="editsettings"
													className="btl-check"
													value={key}
													checked={this.state.editsettings && this.state.editsettings.includes(key)}
													onChange={() => this.onChangeEditSettings(this.state.editsettings && this.state.editsettings.includes(key), key)}
												/>{' '}
												<span className="text">{value}</span>
											</label>
										))}
									</div>
								</div>
								<div className="btl-role-item btl-form-group">
									<label className="btl-form-label">
										<span style={{ display: 'block' }}>{__('Who can Mark Links', 'betterlinks-pro')}</span>
										{__('as Favorite/Unfavorite?', 'betterlinks-pro')}{' '}
									</label>
									<div className="edit-favorite link-options__body">
										{Object.entries(roles).map(([key, value], index) => (
											<label htmlFor={`editFavorite_${index}`} key={`editFavorite_${index}`} className="btl-checkbox-field block">
												<input
													id={`editFavorite_${index}`}
													type="checkbox"
													name="editFavorite"
													className="btl-check"
													value={key}
													checked={this.state.editFavorite && this.state.editFavorite.includes(key)}
													onChange={() => this.onChangeEditFavorite(this.state.editFavorite && this.state.editFavorite.includes(key), key)}
												/>{' '}
												<span className="text">{value}</span>
											</label>
										))}
									</div>
								</div>
								<button className="button-primary btn-save-settings" type="submit">
									{this.state.submitLabel}
								</button>
							</form>
						</div>
					</div>
				</div>
			</React.Fragment>
		);
	}
}

RoleManagement.propTypes = propTypes;
RoleManagement.defaultProps = defaultProps;
