import React, { useState, useEffect } from 'react';
import { __ } from '@wordpress/i18n';
import Select from 'react-select';
import axios from 'axios';
import { betterlinkspro_nonce } from './../../utils/helper';
import PropTypes from 'prop-types';
import { parse } from 'query-string';

const propTypes = {};

const defaultProps = {};

export default function Rotation(props) {
	const { value, extra, setFieldValue, target_url } = props;

	const [links, setLinks] = useState(false);

	useEffect(() => {
		if (extra && extra.split_test) {
			fetchLinks(extra.goal_link);
		}
		if (value.length === 0) {
			setFieldValue('dynamic_redirect.value', [
				{ link: target_url, weight: 50 },
				{ link: '', weight: 50 },
			]);
		} else {
			setFieldValue('dynamic_redirect.value[0]', { link: target_url, weight: value[0].weight });
		}
	}, [extra.split_test]);

	const redirectMode = [
		{ value: 'weighted', label: __('Weighted', 'betterlinks-pro') },
		{ value: 'random', label: __('Random', 'betterlinks-pro') },
	];

	const alreadyUsedWeight = (skipIndex = null) => {
		return props.value.reduce((acc, item, index) => {
			if (skipIndex !== index) {
				return acc + item.weight;
			}
			return acc;
		}, 0);
	};

	const handleWeightChange = (index, event) => {
		let { value, min, max } = event.target;
		let usedWeight = alreadyUsedWeight(index);
		if (usedWeight) {
			max = parseInt(max - usedWeight);
		}
		value = Math.max(Number(min), Math.min(Number(max), Number(parseInt(value, 10))));
		setFieldValue(`dynamic_redirect.value.${index}.weight`, value);
	};

	const onMenuOpen = () => {
		if (links && links.length == 1) {
			fetchLinks();
		}
	};

	const fetchLinks = (ID = null) => {
		let form_data = new FormData();
		form_data.append('action', 'betterlinkspro/admin/get_links');
		form_data.append('security', betterlinkspro_nonce);
		if (ID) {
			form_data.append('ID', ID);
		}
		axios.post(ajaxurl, form_data).then(
			(response) => {
				if (response.data && response.data.data.length > 0) {
					setLinks(
						response.data.data.reduce((acc, item, index) => {
							acc.push({ label: item.link_title, value: item.ID });
							return acc;
						}, [])
					);
				}
			},
			(error) => {
				console.log(error);
			}
		);
	};

	return (
		<React.Fragment>
			<div className="btl-modal-form-group">
				<label className="btl-modal-form-label">{__('Redirect Mode', 'betterlinks-pro')}</label>
				<Select
					className="btl-modal-select--full"
					classNamePrefix="btl-react-select"
					defaultValue={redirectMode.filter((item, index) => item.value == extra.rotation_mode)}
					options={redirectMode}
					onChange={(option) => {
						props.setFieldValue('dynamic_redirect.extra.rotation_mode', option.value);
					}}
				/>
			</div>
			<div className="btl-modal-form-group">
				<label className="btl-modal-form-label" style={{ paddingBottom: 0 }}>
					{__('Target URL Rotations', 'betterlinks-pro')}
				</label>
			</div>
			<div className="btl-modal-target-url-group">
				{value.length > 0 &&
					value.map((item, index) => (
						<div className="btl-modal-form-group">
							<div className="btl-modal-form-label btl-small-label">
								{__('Target URL', 'betterlinks-pro')} {index + 1}
							</div>
							<div className="btl-modal-form-data-wrapper">
								<input
									className="btl-modal-form-control"
									type="text"
									value={item.link}
									onChange={(e) => setFieldValue(`dynamic_redirect.value.${index}.link`, e.target.value.replace(/\s+/g, ''))}
									readOnly={index === 0 ? true : false}
								/>
								{extra.rotation_mode === 'weighted' && (
									<span style={{ position: 'relative', marginLeft: 20 }}>
										<input
											className="btl-modal-form-control btl-width-input"
											type="number"
											max="100"
											value={parseInt(item.weight, 10)}
											onChange={(e) => handleWeightChange(index, e)}
										/>
										<span className="btl-input-type">%</span>
									</span>
								)}
								{index !== 0 && (
									<button
										type="button"
										className="btl-delete-button"
										onClick={() =>
											setFieldValue(
												'dynamic_redirect.value',
												value.filter((item, itemIndex) => itemIndex != index)
											)
										}
									>
										<span className="dashicons dashicons-trash"></span>
									</button>
								)}
							</div>
						</div>
					))}
				<div className="btl-modal-form-group">
					<div className="btl-modal-form-label btl-small-label"></div>
					<button
						className="btl-add-link-button"
						type="button"
						onClick={() => setFieldValue('dynamic_redirect.value', [...value, { link: '', weight: parseInt(100 - alreadyUsedWeight()) }])}
					>
						<span className="icon">
							<span className="btl btl-add"></span>
						</span>
						<span className="text">{__('Add New Link', 'betterlinks-pro')}</span>
					</button>
				</div>
			</div>
			<div className="btl-modal-form-group">
				<label className="btl-modal-form-label" style={{ paddingBottom: 0, display: 'flex', alignItems: 'center' }}>
					<input style={{ marginTop: 0 }} type="checkbox" onChange={() => setFieldValue('dynamic_redirect.extra.split_test', !extra.split_test)} checked={extra.split_test} />
					<span style={{ marginLeft: '5px' }}>{__('Enable Split Testing', 'betterlinks-pro')}</span>
				</label>
			</div>
			<div className="btl-modal-form-group">
				{extra && extra.split_test && (
					<>
						<label className="btl-modal-form-label btl-small-label">
							{__('Goal Link', 'betterlinks-pro')}
							<div className="btl-tooltip" style={{ marginLeft: '10px' }}>
								<span className="dashicons dashicons-info-outline"></span>
								<span className="btl-tooltiptext">
									{__('To check the Conversion analytics, make sure that you have "Tracking" option enabled in your respective Goal Link Settings', 'betterlinks-pro')}
								</span>
							</div>
						</label>
						<div>
							{!links && <Select className="btl-modal-select--full" classNamePrefix="btl-react-select" />}
							{links && links.length > 0 && (
								<Select
									className="btl-modal-select--full"
									classNamePrefix="btl-react-select"
									defaultValue={links.length == 1 ? links[0] : []}
									onChange={(link) => setFieldValue('dynamic_redirect.extra.goal_link', link.value)}
									options={links ? links : []}
									onMenuOpen={onMenuOpen}
								/>
							)}
							<p className="goal-link-notice">
								{__(
									'To use Split Testing, make sure that you have created a shortened URL for your Goal Link from BetterLinks Settings. For more info, check out this ',
									'betterlinks-pro'
								)}
								<strong>
									<a href="https://betterlinks.io/docs/create-new-link-betterlinks/" target="_blank" style={{ textDecoration: 'none' }}>
										{__('doc', 'betterlinks-pro')}
									</a>
								</strong>
							</p>
						</div>
					</>
				)}
			</div>
		</React.Fragment>
	);
}

Rotation.propTypes = propTypes;
Rotation.defaultProps = defaultProps;
