import React, { useState, useEffect } from 'react';
import { __ } from '@wordpress/i18n';
import DataTable from 'react-data-table-component';
import { SplitTestGraph } from '../';
import { makeRequest } from '../../utils/helper';

const propTypes = {};

const defaultProps = {};

const columns = [
	{
		name: __('URL', 'betterlinks-pro'),
		selector: 'url',
		sortable: false,
	},
	{
		name: __('Clicks', 'betterlinks-pro'),
		selector: 'clicks',
		sortable: false,
	},
	{
		name: __('Uniques', 'betterlinks-pro'),
		selector: 'uniques',
		sortable: false,
	},
	{
		name: __('Conversions', 'betterlinks-pro'),
		selector: 'conversions',
		sortable: false,
	},
	{
		name: __('Conv Rate', 'betterlinks-pro'),
		selector: 'conversions',
		sortable: false,
		cell: (row) => (
			<div>
				<div style={{ fontWeight: 700 }}>{row.conversions <= row.uniques ? parseInt((row.conversions / row.uniques) * 100) + '%' : ''}</div>
			</div>
		),
	},
];

export default function SplitTest(props) {
	const [data, setData] = useState(false);
	const ID = betterLinksQuery.get('id');
	const fetchAnalytics = () => {
		makeRequest({
			action: 'betterlinkspro/admin/get_split_test_analytics',
			ID,
		}).then((response) => {
			if (response.data) {
				setData(response.data.data);
			}
		});
	};
	useEffect(() => {
		fetchAnalytics();
	}, []);
	return (
		<React.Fragment>
			<div className="btl-split-testing-wrap">
				{data && data.length > 0 && <SplitTestGraph data={data} />}
				<div className="btl-analytic-table-wrapper">
					{data && <DataTable className="btl-analytic-table" title={__('All Clicks', 'betterlinks-pro')} columns={columns} data={data} subHeader persistTableHead />}
				</div>
			</div>
		</React.Fragment>
	);
}

SplitTest.propTypes = propTypes;
SplitTest.defaultProps = defaultProps;
