import * as React from 'react';
import Paper from '@material-ui/core/Paper';
import { Chart, ArgumentAxis, ValueAxis, BarSeries, Title, Legend } from '@devexpress/dx-react-chart-material-ui';
import { withStyles } from '@material-ui/core/styles';
import { Stack, Animation } from '@devexpress/dx-react-chart';
import { __ } from '@wordpress/i18n';

const legendStyles = () => ({
	root: {
		display: 'flex',
		margin: 'auto',
		flexDirection: 'row',
	},
});
const legendRootBase = ({ classes, ...restProps }) => <Legend.Root {...restProps} className={classes.root} />;
const Root = withStyles(legendStyles, { name: 'LegendRoot' })(legendRootBase);
const legendLabelStyles = () => ({
	label: {
		whiteSpace: 'nowrap',
	},
});
const legendLabelBase = ({ classes, ...restProps }) => <Legend.Label className={classes.label} {...restProps} />;
const Label = withStyles(legendLabelStyles, { name: 'LegendLabel' })(legendLabelBase);

export default class SplitTestGraph extends React.PureComponent {
	constructor(props) {
		super(props);
	}

	render() {
		const data =
			this.props.data &&
			this.props.data.length > 0 &&
			this.props.data.reduce((acc, item, index) => {
				acc.push({
					target_url: item.url,
					clicks: parseInt(item.clicks),
					uniques: parseInt(item.uniques),
					conversions: parseInt(item.conversions),
				});
				return acc;
			}, []);

		return (
			<>
				{this.props.data && (
					<Paper>
						<Chart data={data}>
							<ArgumentAxis />
							<ValueAxis />

							<BarSeries name={__('All Clicks', 'betterlinks-pro')} valueField="clicks" argumentField="target_url" color="#1954fa" />
							<BarSeries name={__('Unique Clicks', 'betterlinks-pro')} valueField="uniques" argumentField="target_url" color="#aa02d3" />
							<BarSeries name={__('Conversions', 'betterlinks-pro')} valueField="conversions" argumentField="target_url" color="#fd6862" />
							<Animation />
							<Legend position="bottom" rootComponent={Root} labelComponent={Label} />
							<Title text="BetterLinks - Split Test Analytics" />
							<Stack />
						</Chart>
					</Paper>
				)}
			</>
		);
	}
}
