import React from 'react';
import { __ } from '@wordpress/i18n';
import queryString from 'query-string';
import PropTypes from 'prop-types';
import { create_utm, fetch_all_utm } from './../../utils/helper';

const propTypes = {};

const defaultProps = {};

export default class UTMBuilderPro extends React.Component {
	constructor(props) {
		super(props);
		this.parseUrl = queryString.parseUrl(this.props.targetUrl, { parseFragmentIdentifier: true });
		this.state = {
			UTM: [],
			UTMBuilderState: {
				template_name: '',
				utm_source: this.parseUrl.query.utm_source ? this.parseUrl.query.utm_source : '',
				utm_medium: this.parseUrl.query.utm_medium ? this.parseUrl.query.utm_medium : '',
				utm_campaign: this.parseUrl.query.utm_campaign ? this.parseUrl.query.utm_campaign : '',
				utm_term: this.parseUrl.query.utm_term ? this.parseUrl.query.utm_term : '',
				utm_content: this.parseUrl.query.utm_content ? this.parseUrl.query.utm_content : '',
			},
			isOpenSavedTemplateName: false,
			savedTemplate: '',
		};

		this.UTMSaveValueHandler = this.UTMSaveValueHandler.bind(this);
		this.createUTM = this.createUTM.bind(this);
		this.changeSavedTemplateHandler = this.changeSavedTemplateHandler.bind(this);
	}

	componentDidMount() {
		fetch_all_utm().then((response) => {
			this.setState({ ...this.state, UTM: response.data });
		});
	}

	UTMSaveValueHandler() {
		const rawURL = queryString.exclude(this.props.targetUrl, ['utm_source', 'utm_medium', 'utm_campaign', 'utm_term', 'utm_content']);
		this.props.setFieldValue(
			'target_url',
			queryString.stringifyUrl({
				url: rawURL,
				query: Object.entries(this.state.UTMBuilderState).reduce((a, [k, v]) => (!v || v == '' || k == 'template_name' ? a : ((a[k] = v), a)), {}),
			})
		);
		this.props.closeUTMModal();
	}

	createUTM() {
		create_utm(this.state.UTMBuilderState).then((response) => {
			this.setState({
				...this.state,
				UTM: response.data,
				UTMBuilderState: {
					template_name: '',
					utm_source: '',
					utm_medium: '',
					utm_campaign: '',
					utm_term: '',
					utm_content: '',
				},
				isOpenSavedTemplateName: false,
			});
		});
	}

	changeSavedTemplateHandler(event) {
		if (event.target.value !== '') {
			this.setState({
				...this.state,
				UTMBuilderState: { ...this.state.UTM[event.target.value] },
				savedTemplate: event.target.value,
			});
		} else {
			this.setState({
				...this.state,
				UTMBuilderState: {
					template_name: '',
					utm_source: '',
					utm_medium: '',
					utm_campaign: '',
					utm_term: '',
					utm_content: '',
				},
				savedTemplate: event.target.value,
			});
		}
	}

	render() {
		return (
			<React.Fragment>
				<div className="btl-modal-utm-builder">
					<h3 className="btl-modal-utm-builder__title">
						{__('UTM Builder', 'betterlinks-pro')}
						<div className="btl-tooltip">
							<span className="dashicons dashicons-info-outline"></span>
							<span className="btl-tooltiptext">{__('Add Campaign Parameters to Track Custom Campaigns', 'betterlinks-pro')}</span>
						</div>
					</h3>
					<div className="btl-modal-utm-builder__body">
						<div className="btl-modal-utm-builder__form-group btl-modal-utm-templates">
							<label htmlFor="savedtemplate">{__('Template', 'betterlinks-pro')}</label>
							<div>
								<select name="savedtemplate" id="savedtemplate" onChange={this.changeSavedTemplateHandler}>
									<option value="">{__('No Template Chosen', 'betterlinks-pro')}</option>
									{this.state.UTM &&
										this.state.UTM.map((item, index) => (
											<option value={index} key={index}>
												{item.template_name}
											</option>
										))}
								</select>
							</div>
						</div>
						<div className="btl-modal-utm-builder__form-group">
							<label htmlFor="utmCampaign">{__('Campaign', 'betterlinks-pro')}</label>
							<div>
								<input
									id="utmCampaign"
									value={this.state.UTMBuilderState.utm_campaign}
									onChange={(e) =>
										this.setState({
											UTMBuilderState: {
												...this.state.UTMBuilderState,
												utm_campaign: e.target.value,
											},
										})
									}
									type="text"
									name="utm_campaign"
									placeholder={__('e.g: Example-Campaign', 'betterlinks-pro')}
								/>
							</div>
						</div>
						<div className="btl-modal-utm-builder__form-group">
							<label htmlFor="utmMedium">{__('Medium', 'betterlinks-pro')}</label>
							<div>
								<input
									id="utmMedium"
									value={this.state.UTMBuilderState.utm_medium}
									onChange={(e) =>
										this.setState({
											UTMBuilderState: {
												...this.state.UTMBuilderState,
												utm_medium: e.target.value,
											},
										})
									}
									type="text"
									name="utm_medium"
									placeholder={__('e.g: cpc, banner, email', 'betterlinks-pro')}
								/>
							</div>
						</div>
						<div className="btl-modal-utm-builder__form-group">
							<label htmlFor="utmSource">{__('Source', 'betterlinks-pro')}</label>
							<div>
								<input
									id="utmSource"
									value={this.state.UTMBuilderState.utm_source}
									onChange={(e) =>
										this.setState({
											UTMBuilderState: {
												...this.state.UTMBuilderState,
												utm_source: e.target.value,
											},
										})
									}
									type="text"
									name="utm_source"
									placeholder={__('e.g: Twitter, Facebook', 'betterlinks-pro')}
								/>
							</div>
						</div>
						<div className="btl-modal-utm-builder__form-group">
							<label htmlFor="utmTerm">{__('Term', 'betterlinks-pro')}</label>
							<div>
								<input
									id="utmTerm"
									value={this.state.UTMBuilderState.utm_term}
									onChange={(e) =>
										this.setState({
											UTMBuilderState: {
												...this.state.UTMBuilderState,
												utm_term: e.target.value,
											},
										})
									}
									type="text"
									name="utm_term"
									placeholder={__('e.g: paid keywords', 'betterlinks-pro')}
								/>
							</div>
						</div>
						<div className="btl-modal-utm-builder__form-group">
							<label htmlFor="utmContent">{__('Content', 'betterlinks-pro')}</label>
							<div>
								<input
									id="utmContent"
									value={this.state.UTMBuilderState.utm_content}
									onChange={(e) =>
										this.setState({
											UTMBuilderState: {
												...this.state.UTMBuilderState,
												utm_content: e.target.value,
											},
										})
									}
									type="text"
									name="utm_content"
									placeholder={__('e.g: text AD name', 'betterlinks-pro')}
								/>
							</div>
						</div>
						<div className="btl-modal-utm-builder__form-group">
							<button type="button" onClick={this.UTMSaveValueHandler}>
								{__('Save Link', 'betterlinks-pro')}
							</button>
							{!this.state.savedTemplate && (
								<div className="template-save-button-wrapper">
									{this.state.isOpenSavedTemplateName ? (
										<div className="template-save-input-wrapper">
											<input
												type="text"
												name="template_name"
												value={this.state.UTMBuilderState.template_name}
												onChange={(e) =>
													this.setState({
														UTMBuilderState: { ...this.state.UTMBuilderState, template_name: e.target.value.length < 31 ? e.target.value : e.target.value.slice(0, -1) },
													})
												}
											/>
											<button type="button" onClick={() => this.state.UTMBuilderState.template_name.trim() != '' && this.createUTM()}>
												<span>{__('Save', 'betterlinks-pro')}</span>
											</button>
										</div>
									) : (
										<button type="button" onClick={(e) => this.setState({ isOpenSavedTemplateName: !this.state.isOpenSavedTemplateName })}>
											{__('Save New Template', 'betterlinks-pro')}
										</button>
									)}
								</div>
							)}
						</div>
					</div>
				</div>
			</React.Fragment>
		);
	}
}

UTMBuilderPro.propTypes = propTypes;
UTMBuilderPro.defaultProps = defaultProps;
