import axios from 'axios';
import { __ } from '@wordpress/i18n';
export const {
	betterlinkspro_nonce,
	nonce,
	rest_url,
	namespace,
	site_url,
	plugin_root_url,
	plugin_root_path,
	route_path,
	page,
	roles,
	user_can_write_links,
	user_can_edit_links,
	user_can_view_links,
	user_can_check_analytics,
	user_can_edit_settings,
	user_can_edit_favorite,
	user_can_manage_options,
} = window.betterLinksProGlobal;

export const API = axios.create({
	baseURL: rest_url,
	headers: {
		'content-type': 'application/json',
		'X-WP-Nonce': nonce,
	},
});

export const create_utm = async (params) => {
	return await API.post(namespace + 'utm', params);
};

export const fetch_all_utm = async () => {
	const res = await API.get(namespace + 'utm');
	return res;
};

export const delayStatusChanged = (firstStatus, secondStatus, thirdStatus, setState) => {
	if (firstStatus) {
		setState(firstStatus);
	}
	setTimeout(() => {
		if (secondStatus) {
			setState(secondStatus);
		}
		if (thirdStatus) {
			setTimeout(() => {
				setState(thirdStatus);
			}, 3000);
		}
	}, 1000);
};

export const getJsonString = (str) => {
	if (Array.isArray(str) || typeof str == 'object') return str;
	try {
		return JSON.parse(str);
	} catch (e) {
		return {};
	}
};
export const makeRequest = async (payload = {}) => {
	let form_data = new FormData();
	form_data.append('security', betterlinkspro_nonce);
	Object.entries(payload).forEach(([key, value]) => {
		if (typeof value === 'object' && value !== null) {
			form_data.append(key, JSON.stringify(value));
		} else {
			form_data.append(key, value);
		}
	});
	return await axios.post(ajaxurl, form_data).then(
		(response) => {
			return response;
		},
		(error) => {
			console.log(error);
		}
	);
};

export const copyToClipboard = (copyText) => {
	var tempInput = document.createElement('input');
	tempInput.value = copyText;
	document.body.appendChild(tempInput);
	tempInput.select();
	document.execCommand('copy');
	document.body.removeChild(tempInput);
	return;
};

export const frequentlyOption = [
	{
		label: __('Daily', 'betterlinks-pro'),
		value: 'daily',
	},
	{
		label: __('Weekly', 'betterlinks-pro'),
		value: 'weekly',
	},
	{
		label: __('Monthly', 'betterlinks-pro'),
		value: 'monthly',
	},
	{
		label: __('Yearly', 'betterlinks-pro'),
		value: 'yearly',
	},
];

export const weekOption = new Array('Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday');

export const modalCustomStyles = {
	overlay: {
		background: 'rgba(35, 40, 45, 0.62)',
	},
	content: {
		top: '50%',
		left: '50%',
		right: 'auto',
		bottom: 'auto',
		maxWidth: '850px',
		marginRight: '-50%',
		transform: 'translate(-50%, -50%)',
	},
};

export const modalCustomSmallStyles = {
	overlay: {
		background: 'rgba(35, 40, 45, 0.62)',
	},
	content: {
		top: '50%',
		left: '50%',
		right: 'auto',
		bottom: 'auto',
		maxWidth: '600px',
		marginRight: '-50%',
		transform: 'translate(-50%, -50%)',
	},
};
export const formatDate = (date, format) => {
	const map = {
		mm: date.getMonth() + 1,
		dd: date.getDate(),
		yyyy: date.getFullYear(),
		h: date.getHours(),
		m: date.getMinutes(),
		s: date.getSeconds(),
	};
	return format.replace(/mm|dd|yyyy|h|m|s/gi, (matched) => map[matched]);
};
